==> debestia8.3-0.3b1pl2.zip: debestia8.3-0.3b1pl2/data/npc/scripts/addoner.lua <==
local keywordHandler = KeywordHandler:new()
local npcHandler = NpcHandler:new(keywordHandler)
NpcSystem.parseParameters(npcHandler)

-- OTServ event handling functions start
function onCreatureAppear(cid) npcHandler:onCreatureAppear(cid) end
function onCreatureDisappear(cid) npcHandler:onCreatureDisappear(cid) end
function onCreatureSay(cid, type, msg) npcHandler:onCreatureSay(cid, type, msg) end
function onThink() npcHandler:onThink() end
-- OTServ event handling functions end

local NPC_addons = {
{idm=128,idf=136,name="citizen",numer="pierwszy",addon=1},
{idm=288,idf=289,name="demonhunter",numer="pierwszy",addon=1},
{idm=288,idf=289,name="demonhunter",numer="drugi",addon=2},
{idm=129,idf=137,name="hunter",numer="pierwszy",addon=1},
{idm=130,idf=138,name="mage",numer="pierwszy",addon=1},
{idm=131,idf=139,name="knight",numer="pierwszy",addon=1},
{idm=132,idf=140,name="noblewoman",numer="pierwszy",addon=1},
{idm=132,idf=140,name="nobleman",numer="pierwszy",addon=1},
{idm=133,idf=141,name="summoner",numer="pierwszy",addon=1},
{idm=134,idf=142,name="warrior",numer="pierwszy",addon=1},
{idm=143,idf=147,name="barbarian",numer="pierwszy",addon=1},
{idm=144,idf=148,name="druid",numer="pierwszy",addon=1},
{idm=145,idf=149,name="wizard",numer="pierwszy",addon=1},
{idm=146,idf=150,name="oriental",numer="pierwszy",addon=1},
{idm=151,idf=155,name="pirate",numer="pierwszy",addon=1},
{idm=152,idf=156,name="assassin",numer="pierwszy",addon=1},
{idm=153,idf=157,name="beggar",numer="pierwszy",addon=1},
{idm=154,idf=158,name="shaman",numer="pierwszy",addon=1},
{idm=251,idf=252,name="norsewoman",numer="pierwszy",addon=1},
{idm=251,idf=252,name="norseman",numer="pierwszy",addon=1},
{idm=268,idf=269,name="nightmare",numer="pierwszy",addon=1},
{idm=270,idf=273,name="jester",numer="pierwszy",addon=1},
{idm=278,idf=279,name="brotherhood",numer="pierwszy",addon=1},
{idm=128,idf=136,name="citizen",numer="drugi",addon=2},
{idm=129,idf=137,name="hunter",numer="drugi",addon=2},
{idm=130,idf=138,name="mage",numer="drugi",addon=2},
{idm=131,idf=139,name="knight",numer="drugi",addon=2},
{idm=132,idf=140,name="noblewoman",numer="drugi",addon=2},
{idm=132,idf=140,name="nobleman",numer="drugi",addon=2},
{idm=133,idf=141,name="summoner",numer="drugi",addon=2},
{idm=134,idf=142,name="warrior",numer="drugi",addon=2},
{idm=143,idf=147,name="barbarian",numer="drugi",addon=2},
{idm=144,idf=148,name="druid",numer="drugi",addon=2},
{idm=145,idf=149,name="wizard",numer="drugi",addon=2},
{idm=146,idf=150,name="oriental",numer="drugi",addon=2},
{idm=151,idf=155,name="pirate",numer="drugi",addon=2},
{idm=152,idf=156,name="assassin",numer="drugi",addon=2},
{idm=153,idf=157,name="beggar",numer="drugi",addon=2},
{idm=154,idf=158,name="shaman",numer="drugi",addon=2},
{idm=251,idf=252,name="norsewoman",numer="drugi",addon=2},
{idm=251,idf=252,name="norseman",numer="drugi",addon=2},
{idm=268,idf=269,name="nightmare",numer="drugi",addon=2},
{idm=270,idf=273,name="jester",numer="drugi",addon=2},
{idm=278,idf=279,name="brotherhood",numer="drugi",addon=2}
}

function getAddonByName(msg)
	msg = string.lower(msg)
	for i = 1, table.maxn(NPC_addons) do
		local addon = NPC_addons[i]
		if msgcontains(msg, addon.numer) and msgcontains(msg, addon.name) then
			return addon
		end
	end
	return {idm=0,idf=0,name="",numer=""}
end

function creatureSayCallback(cid, type, msg)
if(npcHandler.focus ~= cid) then
	return false
end

local selected_addon = getAddonByName(msg)

if tonumber(selected_addon.idm) > 0 then
	addon = selected_addon
	selfSay("Chcesz kupic " .. addon.numer .. " addon do stroju " .. addon.name .."?")
	talk_state = 1
elseif (msgcontains(msg, 'yes') or msgcontains(msg, 'tak')) and talk_state == 1 then
	talk_state = 0
	if getPlayerItemCount(cid,2283) >= 1 then
		doPlayerRemoveItem(cid,2283,1)
		selfSay("Otrzymales " .. addon.numer .. " dodatek do stroju " .. addon.name ..".")
		doPlayerAddOutfit(cid, addon.idm, addon.addon)
		doPlayerAddOutfit(cid, addon.idf, addon.addon)
	else
		selfSay("Dodatki do stroju dostaniesz tylko za specjalna addon rune.")
	end
elseif (msgcontains(msg, 'no') or msgcontains(msg, 'nie')) and talk_state == 1 then
	selfSay('Ok. To moze jakis inny dodatek do stroju?')
	talk_state = 0
end

return true
end

npcHandler:setCallback(CALLBACK_MESSAGE_DEFAULT, creatureSayCallback)
npcHandler:addModule(FocusModule:new())

==> debestia8.4-0.3.1pl2.zip: debestia8.4-0.3.1pl2/data/npc/scripts/addoner.lua <==
local keywordHandler = KeywordHandler:new()
local npcHandler = NpcHandler:new(keywordHandler)
NpcSystem.parseParameters(npcHandler)

-- OTServ event handling functions start
function onCreatureAppear(cid) npcHandler:onCreatureAppear(cid) end
function onCreatureDisappear(cid) npcHandler:onCreatureDisappear(cid) end
function onCreatureSay(cid, type, msg) npcHandler:onCreatureSay(cid, type, msg) end
function onThink() npcHandler:onThink() end
-- OTServ event handling functions end

local NPC_addons = {
{idm=128,idf=136,name="citizen",numer="pierwszy",addon=1},
{idm=288,idf=289,name="demonhunter",numer="pierwszy",addon=1},
{idm=288,idf=289,name="demonhunter",numer="drugi",addon=2},
{idm=129,idf=137,name="hunter",numer="pierwszy",addon=1},
{idm=130,idf=138,name="mage",numer="pierwszy",addon=1},
{idm=131,idf=139,name="knight",numer="pierwszy",addon=1},
{idm=132,idf=140,name="noblewoman",numer="pierwszy",addon=1},
{idm=132,idf=140,name="nobleman",numer="pierwszy",addon=1},
{idm=133,idf=141,name="summoner",numer="pierwszy",addon=1},
{idm=134,idf=142,name="warrior",numer="pierwszy",addon=1},
{idm=143,idf=147,name="barbarian",numer="pierwszy",addon=1},
{idm=144,idf=148,name="druid",numer="pierwszy",addon=1},
{idm=145,idf=149,name="wizard",numer="pierwszy",addon=1},
{idm=146,idf=150,name="oriental",numer="pierwszy",addon=1},
{idm=151,idf=155,name="pirate",numer="pierwszy",addon=1},
{idm=152,idf=156,name="assassin",numer="pierwszy",addon=1},
{idm=153,idf=157,name="beggar",numer="pierwszy",addon=1},
{idm=154,idf=158,name="shaman",numer="pierwszy",addon=1},
{idm=251,idf=252,name="norsewoman",numer="pierwszy",addon=1},
{idm=251,idf=252,name="norseman",numer="pierwszy",addon=1},
{idm=268,idf=269,name="nightmare",numer="pierwszy",addon=1},
{idm=270,idf=273,name="jester",numer="pierwszy",addon=1},
{idm=278,idf=279,name="brotherhood",numer="pierwszy",addon=1},
{idm=128,idf=136,name="citizen",numer="drugi",addon=2},
{idm=129,idf=137,name="hunter",numer="drugi",addon=2},
{idm=130,idf=138,name="mage",numer="drugi",addon=2},
{idm=131,idf=139,name="knight",numer="drugi",addon=2},
{idm=132,idf=140,name="noblewoman",numer="drugi",addon=2},
{idm=132,idf=140,name="nobleman",numer="drugi",addon=2},
{idm=133,idf=141,name="summoner",numer="drugi",addon=2},
{idm=134,idf=142,name="warrior",numer="drugi",addon=2},
{idm=143,idf=147,name="barbarian",numer="drugi",addon=2},
{idm=144,idf=148,name="druid",numer="drugi",addon=2},
{idm=145,idf=149,name="wizard",numer="drugi",addon=2},
{idm=146,idf=150,name="oriental",numer="drugi",addon=2},
{idm=151,idf=155,name="pirate",numer="drugi",addon=2},
{idm=152,idf=156,name="assassin",numer="drugi",addon=2},
{idm=153,idf=157,name="beggar",numer="drugi",addon=2},
{idm=154,idf=158,name="shaman",numer="drugi",addon=2},
{idm=251,idf=252,name="norsewoman",numer="drugi",addon=2},
{idm=251,idf=252,name="norseman",numer="drugi",addon=2},
{idm=268,idf=269,name="nightmare",numer="drugi",addon=2},
{idm=270,idf=273,name="jester",numer="drugi",addon=2},
{idm=278,idf=279,name="brotherhood",numer="drugi",addon=2},
{idm=325,idf=324,name="yalaharian",numer="pierwszy",addon=1},
{idm=325,idf=324,name="yalaharian",numer="drugi",addon=2}
}

function getAddonByName(msg)
	msg = string.lower(msg)
	for i = 1, table.maxn(NPC_addons) do
		local addon = NPC_addons[i]
		if msgcontains(msg, addon.numer) and msgcontains(msg, addon.name) then
			return addon
		end
	end
	return {idm=0,idf=0,name="",numer=""}
end

function creatureSayCallback(cid, type, msg)
if(npcHandler.focus ~= cid) then
	return false
end

local selected_addon = getAddonByName(msg)

if tonumber(selected_addon.idm) > 0 then
	addon = selected_addon
	selfSay("Chcesz kupic " .. addon.numer .. " addon do stroju " .. addon.name .."?")
	talk_state = 1
elseif (msgcontains(msg, 'yes') or msgcontains(msg, 'tak')) and talk_state == 1 then
	talk_state = 0
	if getPlayerItemCount(cid,2283) >= 1 then
		doPlayerRemoveItem(cid,2283,1)
		selfSay("Otrzymales " .. addon.numer .. " dodatek do stroju " .. addon.name ..".")
		doPlayerAddOutfit(cid, addon.idm, addon.addon)
		doPlayerAddOutfit(cid, addon.idf, addon.addon)
	else
		selfSay("Dodatki do stroju dostaniesz tylko za specjalna addon rune.")
	end
elseif (msgcontains(msg, 'no') or msgcontains(msg, 'nie')) and talk_state == 1 then
	selfSay('Ok. To moze jakis inny dodatek do stroju?')
	talk_state = 0
end

return true
end

npcHandler:setCallback(CALLBACK_MESSAGE_DEFAULT, creatureSayCallback)
npcHandler:addModule(FocusModule:new())
